### Python 🐍 Data Science with the TCLab

Welcome to this data science course on Python! This course is intended to help you develop data science and machine learning skills in Python. A [beginning Python course](https://github.com/APMonitor/begin_python) is available for programmers with no prior programming experience. As with the beginning course, this course has video tutorials for each exercise if you have questions along the way. One of the unique things about this course is that you work on basic elements and then test your knowledge with real data exercises with a heat transfer design project. You will see your Python code have a real impact by designing the materials for a new product.

[![Python Data Science](https://apmonitor.com/che263/uploads/Begin_Python/DataScience00.png)](https://www.youtube.com/watch?v=pAgW_bZVo88&list=PLLBUgWXdTBDg1Qgmwt4jKtVn9BWh5-zgy "Python Data Science")

One of the best ways to start or review a programming language is to work on a project. These exercises are designed to teach data science Python programming skills. Data science applications are found across almost all industries where raw data is transformed into actionable information that drives scientific discovery, business innovations, and development. This project is to determine the thermal conductivity of several materials. Thermal conductivity is how well a material conducts or insulates against heat transfer. The specific heat transfer project shows how to apply data science to solve an important problems with methods that are applicable to many different applications.

**Objective**: Collect and analyze data from the TCLab to determine the thermal conductivity of three materials (metal, plastic, and cardboard) that are placed between two temperature sensors. Create a digital twin that predicts heat transfer and temperature.

To make the problem more applicable to a real situation, suppose that you are designing a next-generation cell phone. The battery and processor on the cell phone generate a lot of heat. You want to make sure that the material between them will prevent over-heating of the battery by the processor. This study will help you answer questions about material properties for predicting the temperature of the battery and processor.

**Topics**

There are 12 lessons to help you with the objective of learning data science in Python. The first thing that you will need is to [install Anaconda](https://github.com/APMonitor/data_science/blob/master/00.%20Introduction.ipynb) to open and run the IPython notebook files in Jupyter. Any Python distribution or Integrated Development Environment (IDE) can be used (IDLE (python.org), Spyder, PyCharm, and others) but Jupyter notebook is required to open and run the IPython notebook (`.ipynb`) files. All of the IPython notebook (`.ipynb`) files can be [downloaded at this link](https://github.com/APMonitor/data_science/archive/master.zip). Don't forget to unzip the folder (extract the archive) and copy it to a convenient location before starting.

[![Python Data Science](https://apmonitor.com/che263/uploads/Main/python_data_science.png)](https://www.youtube.com/watch?v=pAgW_bZVo88&list=PLLBUgWXdTBDg1Qgmwt4jKtVn9BWh5-zgy "Python Data Science")

1. [Overview](https://github.com/APMonitor/data_science/blob/master/01.%20Overview.ipynb)
2. [Data Import and Export](https://github.com/APMonitor/data_science/blob/master/02.%20Import_Export.ipynb)
3. [Data Analysis](https://github.com/APMonitor/data_science/blob/master/03.%20Analyze.ipynb)
4. [Visualize Data](https://github.com/APMonitor/data_science/blob/master/04.%20Visualize.ipynb)
5. [Prepare (Cleanse, Scale, Divide) Data](https://github.com/APMonitor/data_science/blob/master/05.%20Prepare_data.ipynb)
6. [Regression](https://github.com/APMonitor/data_science/blob/master/06.%20Regression.ipynb)
7. [Features](https://github.com/APMonitor/data_science/blob/master/07.%20Features.ipynb)
8. [Classification](https://github.com/APMonitor/data_science/blob/master/08.%20Classification.ipynb)
9. [Interpolation](https://github.com/APMonitor/data_science/blob/master/09.%20Interpolation.ipynb)
10. [Solve Equations](https://github.com/APMonitor/data_science/blob/master/10.%20Solve_Equations.ipynb)
11. [Differential Equations](https://github.com/APMonitor/data_science/blob/master/11.%20Differential_Equations.ipynb)
12. [Time Series](https://github.com/APMonitor/data_science/blob/master/12.%20Time_Series.ipynb)

**Get TCLab**

You will need a [TCLab kit](https://apmonitor.com/heat.htm) to complete the exercises.  The TCLab is available for [purchase on Amazon](https://www.amazon.com/TCLab-Temperature-Control-Lab/dp/B07GMFWMRY). 

![Temperature Control Lab](https://apmonitor.com/pdc/uploads/Main/tclab_connect.png "TCLab")

**Install Python**

[Download and install Python](https://www.anaconda.com/products/individual) or watch a video on how to install Python.

**[Install Python on Windows](https://youtu.be/_BHsM452vK0)**

   [![Install Python on Windows](https://img.youtube.com/vi/_BHsM452vK0/0.jpg)](https://www.youtube.com/watch?v=_BHsM452vK0 "Install Python on Windows")

**[Install Python on MacOS](https://youtu.be/2VECcPofhP8)**

   [![Install Python on MacOS](https://img.youtube.com/vi/2VECcPofhP8/0.jpg)](https://www.youtube.com/watch?v=2VECcPofhP8 "Install Python on MacOS")

**[Install Python on Linux](https://youtu.be/eUq-6ZuwC_A)**

   [![Install Python on Linux](https://img.youtube.com/vi/eUq-6ZuwC_A/0.jpg)](https://www.youtube.com/watch?v=eUq-6ZuwC_A "Install Python on Linux")

There are additional instructions on how to [install Python and manage modules](https://apmonitor.com/pdc/index.php/Main/InstallPython).

**Support**

We would love to hear any feedback or problems you would like to send us! We are always trying to improve this course and would like to hear about your experience. We can be contacted at _support@apmonitor.com_.

**Additional Resources**

- [Begin Python Course](https://github.com/APMonitor/begin_python)
- [Engineering Programming Course](https://apmonitor.com/pdc) with [Source Code](https://github.com/APMonitor/learn_python)
- [Temperature Control Lab (TCLab) Kit](https://apmonitor.com/pdc/index.php/Main/ArduinoTemperatureControl)
- [Jupyter as interactive environment for Python, Julia, R](https://jupyter.org/)
